@@ -10,13 +10,26 @@ import glchess.chess
 import glchess.game
 
 # Optionally use OpenGL support
+haveGLSupport = True
 try:
-    import gtk.gtkgl
     import OpenGL.GL
 except:
     haveGLSupport = False
+try:
+    import gtk.gtkgl
+    import gtk.gdkgl
+except:
+    haveGLSupport = False
 else:
-    haveGLSupport = True
+    display_mode = (gtk.gdkgl.MODE_RGB | gtk.gdkgl.MODE_DEPTH | gtk.gdkgl.MODE_DOUBLE)
+    try:
+        glConfig = gtk.gdkgl.Config(mode = display_mode)
+    except gtk.gdkgl.NoMatches:
+        display_mode &= ~gtk.gdkgl.MODE_DOUBLE
+        try:
+            glConfig = gtk.gdkgl.Config(mode = display_mode)
+        except gtk.gdkgl.NoMatches:
+            haveGLSupport = False
 
 __all__ = ['GtkView']
 
@@ -54,7 +67,7 @@ class GtkViewArea(gtk.DrawingArea):
         
         # Make openGL drawable
         if hasattr(gtk, 'gtkgl'):
-            gtk.gtkgl.widget_set_gl_capability(self, self.view.ui.notebook.glConfig)# FIXME:, share_list=glContext)
+            gtk.gtkgl.widget_set_gl_capability(self, glConfig)# FIXME:, share_list=glContext)
 
         # Connect signals
         self.connect('realize', self.__init)
