@@ -20,7 +20,29 @@
 #ifndef _MAIN_H_
 #define _MAIN_H_
 
-gint game_running ();
-gint pause_game_cb (GtkWidget *widget, gpointer data);
+#include <games-scores.h>
+
+#include "gnibbles.h"
+
+#define MAIN_PAGE           	0
+#define NETWORK_PAGE           	1
+
+
+gboolean ggz_network_mode;
+int player_id;
+int num_players;
+int seat;
+int seats[NUMWORMS];
+char names[NUMWORMS][17];
+
+gint game_running (void);
+gint pause_game_cb (GtkAction * action, gpointer data);
+void end_game (gboolean);
+gint new_game (void);
+gint main_loop (gpointer data);
+
+extern GamesScores *highscores;
+extern GtkWidget *notebook;
+extern GtkWidget *window;
 
 #endif
